@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho.pm 3541 2007-10-17T16:04:31.989495Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho.pm 3756 2007-10-19T23:45:38.357303Z lestrrat  $
 # 
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use 5.008;
 use base qw(Gungho::Base);
-use Carp qw(croak);
+use Carp ();
 use Config::Any;
 use Class::Inspector;
 use UNIVERSAL::isa;
@@ -30,7 +30,7 @@ __PACKAGE__->mk_classdata($_) for (
     @CONFIGURABLE_PARAMS,
 );
 
-our $VERSION = '0.08014';
+our $VERSION = '0.08015';
 
 sub new
 {
@@ -109,7 +109,7 @@ sub setup_provider
 
     my $config = $self->config->{provider};
     if (! $config || ref $config ne 'HASH') {
-        croak("Gungho requires a provider");
+        Carp::croak("Gungho requires a provider");
     }
 
     my $pkg = $self->load_gungho_module($config->{module}, 'Provider');
@@ -127,7 +127,7 @@ sub setup_engine
         module => 'POE',
     };
     if (! $config || ref $config ne 'HASH') {
-        croak("Gungho requires a engine");
+        Carp::croak("Gungho requires a engine");
     }
 
     my $pkg = $self->load_gungho_module($config->{module}, 'Engine');
@@ -212,11 +212,11 @@ sub load_config
     }
 
     if (! $config) {
-        croak("Could not load config");
+        Carp::croak("Could not load config");
     }
 
     if (ref $config ne 'HASH') {
-        croak("Gungho expectes config that can be decoded to a HASH");
+        Carp::croak("Gungho expectes config that can be decoded to a HASH");
     }
 
     return $config;
